@@ -1,5 +1,5 @@
 /* Copyright (C) 2012 Benjamin Lewis <benjf5@gmail.com>
- * Copyright (C) 2016-2018 John Donoghue <john.donoghue.ieee.org>
+ * Copyright (C) 2016-2020 John Donoghue <john.donoghue.ieee.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,6 +51,16 @@ the matching sinusoids are a cos (ot) + b i sin (ot).\n\
 
   if (args.length() != 5)
     print_usage();
+  else if (!args(0).is_matrix_type() || args(0).rows() != 1)
+    {
+      error ("fastlscomplex: expected times to be a row vector");
+      return retval;
+    }
+  else if (!args(1).is_matrix_type() || args(1).rows() != 1)
+    {
+      error ("fastlscomplex: expected magnitude to be a row vector");
+      return retval;
+    }
   else
     {
 
@@ -61,26 +71,41 @@ the matching sinusoids are a cos (ot) + b i sin (ot).\n\
       int ncoeff = args(4).int_value ();
 
       if (tvals.numel () != xvals.numel ())
-        if (tvals.numel () > xvals.numel ())
-          error ("fastlscomplex: More time values than magnitude values");
-        else
-          error ("fastlscomplex: More magnitude values than time values");
-      if (ncoeff == 0)
-        error ("fastlscomplex: No coefficients to compute");
-      if (noctaves == 0)
-        error ("fastlscomplex: No octaves to compute over");
-      if (omegamax == 0)
-        error ("fastlscomplex: No difference between minimal and maximal frequency");
-
-      if (! error_state)
         {
-          ComplexRowVector results;
-          if (flscomplex (tvals, xvals, omegamax, noctaves, ncoeff, results))
-            retval(0) = octave_value (results);
+          if (tvals.numel () > xvals.numel ())
+            {
+              error ("fastlscomplex: More time values than magnitude values");
+              return retval;
+            }
           else
-            error ("fastlscomplex: error in the underlying flscomplex function");
+            {
+              error ("fastlscomplex: More magnitude values than time values");
+              return retval;
+            }
+        }
+      if (ncoeff == 0)
+        {
+          error ("fastlscomplex: No coefficients to compute");
+          return retval;
+        }
+      if (noctaves == 0)
+        {
+          error ("fastlscomplex: No octaves to compute over");
+          return retval;
+        }
+      if (omegamax == 0)
+        {
+          error ("fastlscomplex: No difference between minimal and maximal frequency");
+          return retval;
         }
 
+      ComplexRowVector results;
+      if (flscomplex (tvals, xvals, omegamax, noctaves, ncoeff, results))
+        retval(0) = octave_value (results);
+      else
+        {
+          error ("fastlscomplex: error in the underlying flscomplex function");
+        }
     }
 
   return retval;
